==> geosapi_0.6-5.zip: geosapi/NEWS.md <==
## [geosapi 0.6-5](https://cran.r-project.org/package=geosapi) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/package=geosapi)

**Enhancements**

* [#57](https://github.com/eblondel/geosapi/issues/57) Allow namespace based import of GSManager

## [geosapi 0.6-4](https://cran.r-project.org/package=geosapi) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/package=geosapi)

**Enhancements**

* [#55](https://github.com/eblondel/geosapi/issues/55) Support zipped GeoPackage upload

**Documentation**

* [#56](https://github.com/eblondel/geosapi/issues/56) Upgrade roxygen2 Rd to 7.2.1 (html fix)

## [geosapi 0.6-3](https://cran.r-project.org/package=geosapi) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6-3.tar.gz)

**Bug fixes**

* [#54](https://github.com/eblondel/geosapi/issues/54) Error in `getDataStore`(s) - fix wrong XML handling


## [geosapi 0.6-2](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6-2.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6-2.tar.gz)

**Bug fixes**

* [#53](https://github.com/eblondel/geosapi/issues/53) Shapefile upload doesn't work anymore - wrong Content-Type

## [geosapi 0.6-1](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6-1.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6-1.tar.gz)

**Bug fixes**

* [#51](https://github.com/eblondel/geosapi/issues/51) Trailing slash may encounter issue when creating GSManager

## [geosapi 0.6](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6.tar.gz)

**New features**

* [#31](https://github.com/eblondel/geosapi/issues/31) Support for Coverage store class & operations
* [#50](https://github.com/eblondel/geosapi/issues/50) implement system status method + shiny UI

**Enhancements**

* [#52](https://github.com/eblondel/geosapi/issues/52) Standardize R6-class documentation


## [geosapi 0.5-1](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.5-1.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.5-1.tar.gz)

**Enhancements**

* [#49](https://github.com/eblondel/geosapi/issues/49) Better management of keyring backend


## [geosapi 0.5](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.5.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.5.tar.gz)

**New features**

* [#47](https://github.com/eblondel/geosapi/issues/47) Support Geopackage datastore + upload
* [#48](https://github.com/eblondel/geosapi/issues/48) Secure API password with 'keyring'


## [geosapi 0.4-1](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.4-1.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.4-1.tar.gz)

**Bug fixes**

* [#46](https://github.com/eblondel/geosapi/issues/46) CREATE workspace settings doesn't work 

## [geosapi 0.4-0](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.4-0.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.4-0.tar.gz)

**New features**

* [#35](https://github.com/eblondel/geosapi/issues/35) CRUD Workspace Settings operations
* [#36](https://github.com/eblondel/geosapi/issues/36) CRUD OGC Service Settings operations

**Bug fixes**

* [#32](https://github.com/eblondel/geosapi/issues/32) datastore decoding breaks with empty description
* [#33](https://github.com/eblondel/geosapi/issues/33) uploadShapefile returns Internal Server error linked to mimeType
* [#42](https://github.com/eblondel/geosapi/issues/42) Workspace Naming : updateServiceSettings, only lowercased workspace names ?
* [#45](https://github.com/eblondel/geosapi/issues/45) Disable OGC service doesn't work for worskpace settings

**Miscs**

* [#34](https://github.com/eblondel/geosapi/issues/34) unpublishLayer doc typo


## [geosapi 0.3-0](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.3-0.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.3-0.tar.gz)

**New features**

* [#19](https://github.com/eblondel/geosapi/issues/19) Add support for GS Postgis dataStore
* [#25](https://github.com/eblondel/geosapi/issues/25) Add support for GS Oracle NG dataStore
* [#27](https://github.com/eblondel/geosapi/issues/27) Add FeatureType support for CQL Filter

**Bug fixes**

* [#30](https://github.com/eblondel/geosapi/issues/30) `unpublishLayer` bug in if conditions

**Miscs**

* [#23](https://github.com/eblondel/geosapi/issues/23) Add integration tests for GSShapefileDirectoryDataStore



## [geosapi 0.2-0](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.2-0.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.2-0.tar.gz)

**New features**

* [#17](https://github.com/eblondel/geosapi/issues/17) GSFeatureType - encoding/decoding of metadata VirtualTable
* [#22](https://github.com/eblondel/geosapi/issues/22) Add support for GS Directory of shapefiles dataStore
* [#24](https://github.com/eblondel/geosapi/issues/24) Add support for LayerGroup


**Enhancements**

* [#20](https://github.com/eblondel/geosapi/issues/20) Allow inheritance of specific datastore classes


## [geosapi 0.1-0](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.1-0.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.1-0.tar.gz)

**New features**

* [#1](https://github.com/eblondel/geosapi/issues/1) Support of GS workspace - encoding/decoding & CRUD operations
* [#2](https://github.com/eblondel/geosapi/issues/2) Support of GS namespace - encoding/decoding & CRUD operations
* [#3](https://github.com/eblondel/geosapi/issues/3) Support of GS datastore - encoding/decoding & CRUD operations
* [#4](https://github.com/eblondel/geosapi/issues/4) Support of GS ShapeFile datastore - encoding/decoding
* [#5](https://github.com/eblondel/geosapi/issues/5) Support of GS Resource - encoding/decoding & CRUD operations
* [#6](https://github.com/eblondel/geosapi/issues/6) Support of GS FeatureType - encoding/decoding
* [#7](https://github.com/eblondel/geosapi/issues/7) Support of GS Layer - encoding/decoding & CRUD operations
* [#8](https://github.com/eblondel/geosapi/issues/8) Support of GS utils methods to perform http requests (GET, PUT, POST, DELETE)
* [#9](https://github.com/eblondel/geosapi/issues/9) Support GS Manager class (main entrypoint for users)
* [#10](https://github.com/eblondel/geosapi/issues/10) Provide a single generic GS XML Resource encoder
* [#11](https://github.com/eblondel/geosapi/issues/11) Support of GS Version
* [#12](https://github.com/eblondel/geosapi/issues/12) Support of catalog reload operation
* [#13](https://github.com/eblondel/geosapi/issues/13) CRUD operations for styles + getSLDBody method

**Miscs**

* [#18](https://github.com/eblondel/geosapi/issues/18) Set Travis CI docker geoserver instance for integration tests

==> geosapi_0.8.zip: geosapi/NEWS.md <==
## [geosapi 0.8](https://cran.r-project.org/package=geosapi) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/package=geosapi)

**Enhancements**

* [#77](https://github.com/eblondel/geosapi/issues/77) Fetch Geoserver version only once

**New features**

* [#76](https://github.com/eblondel/geosapi/issues/76) Implement Access Control List manager

## [geosapi 0.7-2](https://cran.r-project.org/package=geosapi) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/package=geosapi)

Fix Rdoc requested by CRAN

## [geosapi 0.7-1](https://cran.r-project.org/package=geosapi) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/package=geosapi)

**Corrections**

* [#73](https://github.com/eblondel/geosapi/issues/73) Bad XML encoding for entryset

## [geosapi 0.7](https://cran.r-project.org/package=geosapi) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/package=geosapi)

**Enhancements**

* [#62](https://github.com/eblondel/geosapi/issues/62) Migrate geosapi from XML to xml2
* [#69](https://github.com/eblondel/geosapi/issues/69) Add cli as dependency for nice logs

**New features**

* [#65](https://github.com/eblondel/geosapi/issues/65) Support for Geoserver monitoring plugin API methods
* [#67](https://github.com/eblondel/geosapi/issues/67) Support filename arg for GET methods
* [#68](https://github.com/eblondel/geosapi/issues/68) Support custom printer for `geosapi` objects

## [geosapi 0.6-7](https://cran.r-project.org/package=geosapi) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/package=geosapi)

**Bug fixes**

* [#64](https://github.com/eblondel/geosapi/issues/64) Fix workspace-based style creation/update/delete methods

## [geosapi 0.6-6](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6-6.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6-6.tar.gz)

**Enhancements**

* [#60](https://github.com/eblondel/geosapi/issues/60) Fix base URL used to retrieve Geoserver version
* [#61](https://github.com/eblondel/geosapi/issues/61) Support workspace-based methods `getStyles`, `getStyleNames`


## [geosapi 0.6-5](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6-5.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6-5.tar.gz)

**Enhancements**

* [#57](https://github.com/eblondel/geosapi/issues/57) Allow namespace based import of GSManager

## [geosapi 0.6-4](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6-4.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6-4.tar.gz)

**Enhancements**

* [#55](https://github.com/eblondel/geosapi/issues/55) Support zipped GeoPackage upload

**Documentation**

* [#56](https://github.com/eblondel/geosapi/issues/56) Upgrade roxygen2 Rd to 7.2.1 (html fix)

## [geosapi 0.6-3](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6-3.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6-3.tar.gz)

**Bug fixes**

* [#54](https://github.com/eblondel/geosapi/issues/54) Error in `getDataStore`(s) - fix wrong XML handling


## [geosapi 0.6-2](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6-2.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6-2.tar.gz)

**Bug fixes**

* [#53](https://github.com/eblondel/geosapi/issues/53) Shapefile upload doesn't work anymore - wrong Content-Type

## [geosapi 0.6-1](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6-1.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6-1.tar.gz)

**Bug fixes**

* [#51](https://github.com/eblondel/geosapi/issues/51) Trailing slash may encounter issue when creating GSManager

## [geosapi 0.6](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.6.tar.gz)

**New features**

* [#31](https://github.com/eblondel/geosapi/issues/31) Support for Coverage store class & operations
* [#50](https://github.com/eblondel/geosapi/issues/50) implement system status method + shiny UI

**Enhancements**

* [#52](https://github.com/eblondel/geosapi/issues/52) Standardize R6-class documentation


## [geosapi 0.5-1](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.5-1.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.5-1.tar.gz)

**Enhancements**

* [#49](https://github.com/eblondel/geosapi/issues/49) Better management of keyring backend


## [geosapi 0.5](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.5.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.5.tar.gz)

**New features**

* [#47](https://github.com/eblondel/geosapi/issues/47) Support Geopackage datastore + upload
* [#48](https://github.com/eblondel/geosapi/issues/48) Secure API password with 'keyring'


## [geosapi 0.4-1](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.4-1.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.4-1.tar.gz)

**Bug fixes**

* [#46](https://github.com/eblondel/geosapi/issues/46) CREATE workspace settings doesn't work 

## [geosapi 0.4-0](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.4-0.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.4-0.tar.gz)

**New features**

* [#35](https://github.com/eblondel/geosapi/issues/35) CRUD Workspace Settings operations
* [#36](https://github.com/eblondel/geosapi/issues/36) CRUD OGC Service Settings operations

**Bug fixes**

* [#32](https://github.com/eblondel/geosapi/issues/32) datastore decoding breaks with empty description
* [#33](https://github.com/eblondel/geosapi/issues/33) uploadShapefile returns Internal Server error linked to mimeType
* [#42](https://github.com/eblondel/geosapi/issues/42) Workspace Naming : updateServiceSettings, only lowercased workspace names ?
* [#45](https://github.com/eblondel/geosapi/issues/45) Disable OGC service doesn't work for worskpace settings

**Miscs**

* [#34](https://github.com/eblondel/geosapi/issues/34) unpublishLayer doc typo


## [geosapi 0.3-0](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.3-0.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.3-0.tar.gz)

**New features**

* [#19](https://github.com/eblondel/geosapi/issues/19) Add support for GS Postgis dataStore
* [#25](https://github.com/eblondel/geosapi/issues/25) Add support for GS Oracle NG dataStore
* [#27](https://github.com/eblondel/geosapi/issues/27) Add FeatureType support for CQL Filter

**Bug fixes**

* [#30](https://github.com/eblondel/geosapi/issues/30) `unpublishLayer` bug in if conditions

**Miscs**

* [#23](https://github.com/eblondel/geosapi/issues/23) Add integration tests for GSShapefileDirectoryDataStore



## [geosapi 0.2-0](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.2-0.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.2-0.tar.gz)

**New features**

* [#17](https://github.com/eblondel/geosapi/issues/17) GSFeatureType - encoding/decoding of metadata VirtualTable
* [#22](https://github.com/eblondel/geosapi/issues/22) Add support for GS Directory of shapefiles dataStore
* [#24](https://github.com/eblondel/geosapi/issues/24) Add support for LayerGroup


**Enhancements**

* [#20](https://github.com/eblondel/geosapi/issues/20) Allow inheritance of specific datastore classes


## [geosapi 0.1-0](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.1-0.tar.gz) | [![CRAN_Status_Badge](https://img.shields.io/badge/CRAN-published-blue.svg)](https://cran.r-project.org/src/contrib/Archive/geosapi/geosapi_0.1-0.tar.gz)

**New features**

* [#1](https://github.com/eblondel/geosapi/issues/1) Support of GS workspace - encoding/decoding & CRUD operations
* [#2](https://github.com/eblondel/geosapi/issues/2) Support of GS namespace - encoding/decoding & CRUD operations
* [#3](https://github.com/eblondel/geosapi/issues/3) Support of GS datastore - encoding/decoding & CRUD operations
* [#4](https://github.com/eblondel/geosapi/issues/4) Support of GS ShapeFile datastore - encoding/decoding
* [#5](https://github.com/eblondel/geosapi/issues/5) Support of GS Resource - encoding/decoding & CRUD operations
* [#6](https://github.com/eblondel/geosapi/issues/6) Support of GS FeatureType - encoding/decoding
* [#7](https://github.com/eblondel/geosapi/issues/7) Support of GS Layer - encoding/decoding & CRUD operations
* [#8](https://github.com/eblondel/geosapi/issues/8) Support of GS utils methods to perform http requests (GET, PUT, POST, DELETE)
* [#9](https://github.com/eblondel/geosapi/issues/9) Support GS Manager class (main entrypoint for users)
* [#10](https://github.com/eblondel/geosapi/issues/10) Provide a single generic GS XML Resource encoder
* [#11](https://github.com/eblondel/geosapi/issues/11) Support of GS Version
* [#12](https://github.com/eblondel/geosapi/issues/12) Support of catalog reload operation
* [#13](https://github.com/eblondel/geosapi/issues/13) CRUD operations for styles + getSLDBody method

**Miscs**

* [#18](https://github.com/eblondel/geosapi/issues/18) Set Travis CI docker geoserver instance for integration tests
